@@ -913,6 +913,7 @@ class CanvasMainWindow(QMainWindow):
                 statistics = scheme_widget.usageStatistics()
                 statistics.begin_action(UsageStatistics.ToolboxClick)
                 scheme_widget.createNewNode(widget_desc)
+                scheme_widget.view().setFocus(Qt.OtherFocusReason)
 
     def on_quick_category_action(self, action):
         """The quick category menu action triggered.
@@ -2482,7 +2483,14 @@ class CanvasMainWindow(QMainWindow):
                                             defaultValue=True,
                                             type=bool)
         self.scheme_widget.setChannelNamesVisible(show_channel_names)
-
+        open_anchors_ = settings.value(
+            "open-anchors-on-hover", defaultValue=False, type=bool
+        )
+        if open_anchors_:
+            open_anchors = SchemeEditWidget.OpenAnchors.Always
+        else:
+            open_anchors = SchemeEditWidget.OpenAnchors.OnShift
+        self.scheme_widget.setOpenAnchorsMode(open_anchors)
         node_animations = settings.value("enable-node-animations",
                                          defaultValue=False,
                                          type=bool)
