@@ -24,13 +24,13 @@ from AnyQt.QtWidgets import (
     QStyleOptionViewItem, QSizeGrip, QAbstractItemView, QStyledItemDelegate
 )
 from AnyQt.QtGui import (
-    QIcon, QStandardItemModel, QBrush, QPalette, QPaintEvent, QColor, QPainter,
-    QMouseEvent,
+    QIcon, QStandardItemModel, QPolygon, QRegion, QBrush, QPalette,
+    QPaintEvent, QColor, QPainter, QMouseEvent
 )
 from AnyQt.QtCore import (
     Qt, QObject, QPoint, QPointF, QSize, QRect, QRectF, QEventLoop, QEvent,
-    QModelIndex, QRegularExpression, QSortFilterProxyModel, QItemSelectionModel,
-    QAbstractItemModel, QSettings
+    QModelIndex, QTimer, QRegularExpression, QSortFilterProxyModel,
+    QItemSelectionModel, QAbstractItemModel, QSettings
 )
 from AnyQt.QtCore import pyqtSignal as Signal, pyqtProperty as Property
 
@@ -780,6 +780,11 @@ class TabBarWidget(QWidget):
         )
         self.setMouseTracking(True)
 
+        self.__sloppyButton = None  # type: Optional[QAbstractButton]
+        self.__sloppyRegion = QRegion()
+        self.__sloppyTimer = QTimer(self, singleShot=True)
+        self.__sloppyTimer.timeout.connect(self.__onSloppyTimeout)
+
         self.currentChanged.connect(self.__updateShadows)
 
     def setChangeOnHover(self, changeOnHover):
@@ -857,6 +862,11 @@ class TabBarWidget(QWidget):
             self.__group.removeButton(tab.button)
 
             tab.button.removeEventFilter(self)
+
+            if tab.button is self.__sloppyButton:
+                self.__sloppyButton = None
+                self.__sloppyRegion = QRegion()
+
             tab.button.deleteLater()
             tab.button.setParent(None)
 
@@ -908,6 +918,9 @@ class TabBarWidget(QWidget):
         if self.__currentIndex != index:
             self.__currentIndex = index
 
+            self.__sloppyRegion = QRegion()
+            self.__sloppyButton = None
+
             if index != -1:
                 self.__tabs[index].button.setChecked(True)
 
@@ -989,16 +1002,64 @@ class TabBarWidget(QWidget):
                 self.setCurrentIndex(i)
                 break
 
+    def __calcSloppyRegion(self, current):
+        # type: (QPoint) -> QRegion
+        """
+        Given a current mouse cursor position return a region of the widget
+        where hover/move events should change the current tab only on a
+        timeout.
+        """
+        p1 = current + QPoint(0, 2)
+        p2 = current + QPoint(0, -2)
+        p3 = self.pos() + QPoint(self.width()+10, 0)
+        p4 = self.pos() + QPoint(self.width()+10, self.height())
+        return QRegion(QPolygon([p1, p2, p3, p4]))
+
+    def __setSloppyButton(self, button):
+        # type: (QAbstractButton) -> None
+        """
+        Set the current sloppy button (a tab button inside sloppy region)
+        and reset the sloppy timeout.
+        """
+        if not button.isChecked():
+            self.__sloppyButton = button
+            delay = self.style().styleHint(QStyle.SH_Menu_SubMenuPopupDelay, None)
+            # The delay timeout is the same as used by Qt in the QMenu.
+            self.__sloppyTimer.start(delay)
+        else:
+            self.__sloppyTimer.stop()
+
+    def __onSloppyTimeout(self):
+        # type: () -> None
+        if self.__sloppyButton is not None:
+            button = self.__sloppyButton
+            self.__sloppyButton = None
+            if not button.isChecked():
+                index = [tab.button for tab in self.__tabs].index(button)
+                self.setCurrentIndex(index)
+
     def eventFilter(self, receiver, event):
         if event.type() == QEvent.MouseMove and \
                 isinstance(receiver, TabButton) and \
                 self.__changeOnHover:
             pos = receiver.mapTo(self, event.pos())
-            if not receiver.isChecked():
-                index = [tab.button for tab in self.__tabs].index(receiver)
-                self.setCurrentIndex(index)
+            if self.__sloppyRegion.contains(pos):
+                self.__setSloppyButton(receiver)
+            else:
+                if not receiver.isChecked():
+                    index = [tab.button for tab in self.__tabs].index(receiver)
+                    self.setCurrentIndex(index)
+                #also update sloppy region if mouse is moved on the same icon
+                self.__sloppyRegion = self.__calcSloppyRegion(pos)
+
         return super().eventFilter(receiver, event)
 
+    def leaveEvent(self, event):
+        self.__sloppyButton = None
+        self.__sloppyRegion = QRegion()
+
+        return super().leaveEvent(event)
+
 
 class PagedMenu(QWidget):
     """
