@@ -2,6 +2,7 @@
 Helper utilities
 
 """
+import os
 import sys
 import traceback
 from typing import List
@@ -181,6 +182,21 @@ def is_dwm_compositing_enabled():  # type: () -> bool
     return rval == 0 and enabled.value
 
 
+def windows_set_current_process_app_user_model_id(appid: str):
+    """
+    On Windows set the AppUserModelID to `appid` for the current process.
+
+    Does nothing on other systems
+    """
+    if os.name != "nt":
+        return
+    from ctypes import windll
+    try:
+        windll.shell32.SetCurrentProcessExplicitAppUserModelID(appid)
+    except AttributeError:
+        pass
+
+
 def macos_set_nswindow_tabbing(enable=False):
     # type: (bool) -> None
     """
@@ -195,7 +211,7 @@ def macos_set_nswindow_tabbing(enable=False):
     if ver < (10, 12):
         return
 
-    c_char_p, c_void_p = ctypes.c_char_p, ctypes.c_void_p
+    c_char_p, c_void_p, c_bool = ctypes.c_char_p, ctypes.c_void_p, ctypes.c_bool
     id = Sel = Class = c_void_p
 
     def annotate(func, restype, argtypes):
@@ -209,8 +225,10 @@ def macos_set_nswindow_tabbing(enable=False):
         AppKit = ctypes.cdll.LoadLibrary(ctypes.util.find_library("AppKit"))
         objc_getClass = annotate(
             libobjc.objc_getClass, Class, [c_char_p])
-        objc_msgSend = annotate(
-            libobjc.objc_msgSend, id, [id, Sel])
+        # A prototype for objc_msgSend for selector with a bool argument.
+        # `(void *)(*)(void *, void *, bool)`
+        objc_msgSend_bool = annotate(
+            libobjc.objc_msgSend, id, [id, Sel, c_bool])
         sel_registerName = annotate(
             libobjc.sel_registerName, Sel, [c_char_p])
         class_getClassMethod = annotate(
@@ -227,10 +245,10 @@ def macos_set_nswindow_tabbing(enable=False):
     # class_respondsToSelector does not work (for class methods)
     if class_getClassMethod(NSWindow, setAllowsAutomaticWindowTabbing):
         # [NSWindow setAllowsAutomaticWindowTabbing: NO]
-        objc_msgSend(
+        objc_msgSend_bool(
             NSWindow,
             setAllowsAutomaticWindowTabbing,
-            ctypes.c_bool(enable),
+            c_bool(enable),
         )
 
 
